package net.wanji.databus.config;

import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.databind.JsonSerializer;
import com.fasterxml.jackson.databind.SerializerProvider;
import net.wanji.common.utils.tool.JacksonUtils;

import java.io.IOException;
import java.math.BigDecimal;
import java.text.DecimalFormat;

/**
 * @author duanruiming
 * @date 2024/12/01 16:17
 */
public class DoubleToTwoDecimalPlacesSerializer extends JsonSerializer<Double> {
    private static final DecimalFormat df = new DecimalFormat("#0.00");

    @Override
    public void serialize(Double value, JsonGenerator gen, SerializerProvider serializers) throws IOException {
        if (value != null) {
            // 将 Double 转换为 BigDecimal，避免浮点数精度问题
            BigDecimal bd = BigDecimal.valueOf(value).setScale(2, BigDecimal.ROUND_HALF_UP);
            String formattedValue = df.format(bd.doubleValue());
            gen.writeString(formattedValue);
        } else {
            gen.writeNull();
        }
    }
}
