package net.wanji.databus.vo;

import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.Pattern;

/**
 * 信号机临时方案下发VO
 *
 * @author zhouleilei
 * @date 2024/11/4 16:14:27
 */
@Data
public class TempSchemeSendVO {

    @ApiModelProperty(value = "路口编号", notes = "路口编号")
    @Pattern(regexp = "^[A-Za-z0-9]{11}$", message = "路口编号只能包含英文、数字，必须11个字符")
    @NotBlank(message = "路口编号不可为空")
    private String crossId;

    @ApiModelProperty(value = "基础方案号", notes = "优化的基础方案号，该方案号需在信号机提前配置")
    @NotBlank(message = "基础方案号pattern不能为空")
    private String pattern;

    @ApiModelProperty(value = "周期长", notes = "需要优化的周期长，单位秒")
    @NotBlank(message = "cycle不能为空")
    private String cycle;

    @ApiModelProperty(value = "相位差", notes = "相位差。需要优化的相位差，单位秒")
    @NotBlank(message = "offset不能为空")
    private String offset;

    @ApiModelProperty(value = "优化模式", notes = "目前支持 Type=1（预案模式，按时间调整），Type=9 时为协调模式，Type=15（瓶颈模式，按比例调整）")
    @NotBlank(message = "type不能为空")
    private String type;

    @ApiModelProperty(value = "绿信比时间", notes = "Type=1 时为预案模式，值为绿信比时间，Type=15 时为瓶颈模式，值为调整比例")
    @NotBlank(message = "split不能为空")
    private String split;
}
